Class: Aws::FIS::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::FIS::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-fis/client.rb,
sig/client.rbs
Overview
An API client for FIS. To construct a client, you need to configure a :region and :credentials.
client = Aws::FIS::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateExperimentTemplateResponseSuccess, _CreateTargetAccountConfigurationResponseSuccess, _DeleteExperimentTemplateResponseSuccess, _DeleteTargetAccountConfigurationResponseSuccess, _GetActionResponseSuccess, _GetExperimentResponseSuccess, _GetExperimentTargetAccountConfigurationResponseSuccess, _GetExperimentTemplateResponseSuccess, _GetSafetyLeverResponseSuccess, _GetTargetAccountConfigurationResponseSuccess, _GetTargetResourceTypeResponseSuccess, _ListActionsResponseSuccess, _ListExperimentResolvedTargetsResponseSuccess, _ListExperimentTargetAccountConfigurationsResponseSuccess, _ListExperimentTemplatesResponseSuccess, _ListExperimentsResponseSuccess, _ListTagsForResourceResponseSuccess, _ListTargetAccountConfigurationsResponseSuccess, _ListTargetResourceTypesResponseSuccess, _StartExperimentResponseSuccess, _StopExperimentResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateExperimentTemplateResponseSuccess, _UpdateSafetyLeverStateResponseSuccess, _UpdateTargetAccountConfigurationResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_experiment_template(params = {}) ⇒ Types::CreateExperimentTemplateResponse
Creates an experiment template.
-
#create_target_account_configuration(params = {}) ⇒ Types::CreateTargetAccountConfigurationResponse
Creates a target account configuration for the experiment template.
-
#delete_experiment_template(params = {}) ⇒ Types::DeleteExperimentTemplateResponse
Deletes the specified experiment template.
-
#delete_target_account_configuration(params = {}) ⇒ Types::DeleteTargetAccountConfigurationResponse
Deletes the specified target account configuration of the experiment template.
-
#get_action(params = {}) ⇒ Types::GetActionResponse
Gets information about the specified FIS action.
-
#get_experiment(params = {}) ⇒ Types::GetExperimentResponse
Gets information about the specified experiment.
-
#get_experiment_target_account_configuration(params = {}) ⇒ Types::GetExperimentTargetAccountConfigurationResponse
Gets information about the specified target account configuration of the experiment.
-
#get_experiment_template(params = {}) ⇒ Types::GetExperimentTemplateResponse
Gets information about the specified experiment template.
-
#get_safety_lever(params = {}) ⇒ Types::GetSafetyLeverResponse
Gets information about the specified safety lever.
-
#get_target_account_configuration(params = {}) ⇒ Types::GetTargetAccountConfigurationResponse
Gets information about the specified target account configuration of the experiment template.
-
#get_target_resource_type(params = {}) ⇒ Types::GetTargetResourceTypeResponse
Gets information about the specified resource type.
-
#list_actions(params = {}) ⇒ Types::ListActionsResponse
Lists the available FIS actions.
-
#list_experiment_resolved_targets(params = {}) ⇒ Types::ListExperimentResolvedTargetsResponse
Lists the resolved targets information of the specified experiment.
-
#list_experiment_target_account_configurations(params = {}) ⇒ Types::ListExperimentTargetAccountConfigurationsResponse
Lists the target account configurations of the specified experiment.
-
#list_experiment_templates(params = {}) ⇒ Types::ListExperimentTemplatesResponse
Lists your experiment templates.
-
#list_experiments(params = {}) ⇒ Types::ListExperimentsResponse
Lists your experiments.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for the specified resource.
-
#list_target_account_configurations(params = {}) ⇒ Types::ListTargetAccountConfigurationsResponse
Lists the target account configurations of the specified experiment template.
-
#list_target_resource_types(params = {}) ⇒ Types::ListTargetResourceTypesResponse
Lists the target resource types.
-
#start_experiment(params = {}) ⇒ Types::StartExperimentResponse
Starts running an experiment from the specified experiment template.
-
#stop_experiment(params = {}) ⇒ Types::StopExperimentResponse
Stops the specified experiment.
-
#tag_resource(params = {}) ⇒ Struct
Applies the specified tags to the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes the specified tags from the specified resource.
-
#update_experiment_template(params = {}) ⇒ Types::UpdateExperimentTemplateResponse
Updates the specified experiment template.
-
#update_safety_lever_state(params = {}) ⇒ Types::UpdateSafetyLeverStateResponse
Updates the specified safety lever state.
-
#update_target_account_configuration(params = {}) ⇒ Types::UpdateTargetAccountConfigurationResponse
Updates the target account configuration for the specified experiment template.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-fis/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2058 2059 2060 |
# File 'lib/aws-sdk-fis/client.rb', line 2058 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2061 2062 2063 |
# File 'lib/aws-sdk-fis/client.rb', line 2061 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2031 2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 |
# File 'lib/aws-sdk-fis/client.rb', line 2031 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::FIS') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-fis' context[:gem_version] = '1.68.0' Seahorse::Client::Request.new(handlers, context) end |
#create_experiment_template(params = {}) ⇒ Types::CreateExperimentTemplateResponse
Creates an experiment template.
An experiment template includes the following components:
-
Targets: A target can be a specific resource in your Amazon Web Services environment, or one or more resources that match criteria that you specify, for example, resources that have specific tags.
-
Actions: The actions to carry out on the target. You can specify multiple actions, the duration of each action, and when to start each action during an experiment.
-
Stop conditions: If a stop condition is triggered while an experiment is running, the experiment is automatically stopped. You can define a stop condition as a CloudWatch alarm.
For more information, see experiment templates in the Fault Injection Service User Guide.
86 |
# File 'sig/client.rbs', line 86
def create_experiment_template: (
|
#create_target_account_configuration(params = {}) ⇒ Types::CreateTargetAccountConfigurationResponse
Creates a target account configuration for the experiment template. A
target account configuration is required when accountTargeting of
experimentOptions is set to multi-account. For more information,
see experiment options in the Fault Injection Service User
Guide.
156 |
# File 'sig/client.rbs', line 156
def create_target_account_configuration: (
|
#delete_experiment_template(params = {}) ⇒ Types::DeleteExperimentTemplateResponse
Deletes the specified experiment template.
170 |
# File 'sig/client.rbs', line 170
def delete_experiment_template: (
|
#delete_target_account_configuration(params = {}) ⇒ Types::DeleteTargetAccountConfigurationResponse
Deletes the specified target account configuration of the experiment template.
180 |
# File 'sig/client.rbs', line 180
def delete_target_account_configuration: (
|
#get_action(params = {}) ⇒ Types::GetActionResponse
Gets information about the specified FIS action.
191 |
# File 'sig/client.rbs', line 191
def get_action: (
|
#get_experiment(params = {}) ⇒ Types::GetExperimentResponse
Gets information about the specified experiment.
201 |
# File 'sig/client.rbs', line 201
def get_experiment: (
|
#get_experiment_target_account_configuration(params = {}) ⇒ Types::GetExperimentTargetAccountConfigurationResponse
Gets information about the specified target account configuration of the experiment.
211 |
# File 'sig/client.rbs', line 211
def get_experiment_target_account_configuration: (
|
#get_experiment_template(params = {}) ⇒ Types::GetExperimentTemplateResponse
Gets information about the specified experiment template.
222 |
# File 'sig/client.rbs', line 222
def get_experiment_template: (
|
#get_safety_lever(params = {}) ⇒ Types::GetSafetyLeverResponse
Gets information about the specified safety lever.
232 |
# File 'sig/client.rbs', line 232
def get_safety_lever: (
|
#get_target_account_configuration(params = {}) ⇒ Types::GetTargetAccountConfigurationResponse
Gets information about the specified target account configuration of the experiment template.
242 |
# File 'sig/client.rbs', line 242
def get_target_account_configuration: (
|
#get_target_resource_type(params = {}) ⇒ Types::GetTargetResourceTypeResponse
Gets information about the specified resource type.
253 |
# File 'sig/client.rbs', line 253
def get_target_resource_type: (
|
#list_actions(params = {}) ⇒ Types::ListActionsResponse
Lists the available FIS actions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
264 |
# File 'sig/client.rbs', line 264
def list_actions: (
|
#list_experiment_resolved_targets(params = {}) ⇒ Types::ListExperimentResolvedTargetsResponse
Lists the resolved targets information of the specified experiment.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
276 |
# File 'sig/client.rbs', line 276
def list_experiment_resolved_targets: (
|
#list_experiment_target_account_configurations(params = {}) ⇒ Types::ListExperimentTargetAccountConfigurationsResponse
Lists the target account configurations of the specified experiment.
290 |
# File 'sig/client.rbs', line 290
def list_experiment_target_account_configurations: (
|
#list_experiment_templates(params = {}) ⇒ Types::ListExperimentTemplatesResponse
Lists your experiment templates.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
302 |
# File 'sig/client.rbs', line 302
def list_experiment_templates: (
|
#list_experiments(params = {}) ⇒ Types::ListExperimentsResponse
Lists your experiments.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
314 |
# File 'sig/client.rbs', line 314
def list_experiments: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for the specified resource.
326 |
# File 'sig/client.rbs', line 326
def list_tags_for_resource: (
|
#list_target_account_configurations(params = {}) ⇒ Types::ListTargetAccountConfigurationsResponse
Lists the target account configurations of the specified experiment template.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
337 |
# File 'sig/client.rbs', line 337
def list_target_account_configurations: (
|
#list_target_resource_types(params = {}) ⇒ Types::ListTargetResourceTypesResponse
Lists the target resource types.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
350 |
# File 'sig/client.rbs', line 350
def list_target_resource_types: (
|
#start_experiment(params = {}) ⇒ Types::StartExperimentResponse
Starts running an experiment from the specified experiment template.
361 |
# File 'sig/client.rbs', line 361
def start_experiment: (
|
#stop_experiment(params = {}) ⇒ Types::StopExperimentResponse
Stops the specified experiment.
376 |
# File 'sig/client.rbs', line 376
def stop_experiment: (
|
#tag_resource(params = {}) ⇒ Struct
Applies the specified tags to the specified resource.
385 |
# File 'sig/client.rbs', line 385
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes the specified tags from the specified resource.
395 |
# File 'sig/client.rbs', line 395
def untag_resource: (
|
#update_experiment_template(params = {}) ⇒ Types::UpdateExperimentTemplateResponse
Updates the specified experiment template.
406 |
# File 'sig/client.rbs', line 406
def update_experiment_template: (
|
#update_safety_lever_state(params = {}) ⇒ Types::UpdateSafetyLeverStateResponse
Updates the specified safety lever state.
474 |
# File 'sig/client.rbs', line 474
def update_safety_lever_state: (
|
#update_target_account_configuration(params = {}) ⇒ Types::UpdateTargetAccountConfigurationResponse
Updates the target account configuration for the specified experiment template.
488 |
# File 'sig/client.rbs', line 488
def update_target_account_configuration: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2051 2052 2053 |
# File 'lib/aws-sdk-fis/client.rb', line 2051 def waiter_names [] end |