Class: Aws::FIS::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::FIS::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-fis/client.rb
Overview
An API client for FIS. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::FIS::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_experiment_template(params = {}) ⇒ Types::CreateExperimentTemplateResponse
Creates an experiment template.
-
#create_target_account_configuration(params = {}) ⇒ Types::CreateTargetAccountConfigurationResponse
Creates a target account configuration for the experiment template.
-
#delete_experiment_template(params = {}) ⇒ Types::DeleteExperimentTemplateResponse
Deletes the specified experiment template.
-
#delete_target_account_configuration(params = {}) ⇒ Types::DeleteTargetAccountConfigurationResponse
Deletes the specified target account configuration of the experiment template.
-
#get_action(params = {}) ⇒ Types::GetActionResponse
Gets information about the specified FIS action.
-
#get_experiment(params = {}) ⇒ Types::GetExperimentResponse
Gets information about the specified experiment.
-
#get_experiment_target_account_configuration(params = {}) ⇒ Types::GetExperimentTargetAccountConfigurationResponse
Gets information about the specified target account configuration of the experiment.
-
#get_experiment_template(params = {}) ⇒ Types::GetExperimentTemplateResponse
Gets information about the specified experiment template.
-
#get_safety_lever(params = {}) ⇒ Types::GetSafetyLeverResponse
Gets information about the specified safety lever.
-
#get_target_account_configuration(params = {}) ⇒ Types::GetTargetAccountConfigurationResponse
Gets information about the specified target account configuration of the experiment template.
-
#get_target_resource_type(params = {}) ⇒ Types::GetTargetResourceTypeResponse
Gets information about the specified resource type.
-
#list_actions(params = {}) ⇒ Types::ListActionsResponse
Lists the available FIS actions.
-
#list_experiment_resolved_targets(params = {}) ⇒ Types::ListExperimentResolvedTargetsResponse
Lists the resolved targets information of the specified experiment.
-
#list_experiment_target_account_configurations(params = {}) ⇒ Types::ListExperimentTargetAccountConfigurationsResponse
Lists the target account configurations of the specified experiment.
-
#list_experiment_templates(params = {}) ⇒ Types::ListExperimentTemplatesResponse
Lists your experiment templates.
-
#list_experiments(params = {}) ⇒ Types::ListExperimentsResponse
Lists your experiments.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for the specified resource.
-
#list_target_account_configurations(params = {}) ⇒ Types::ListTargetAccountConfigurationsResponse
Lists the target account configurations of the specified experiment template.
-
#list_target_resource_types(params = {}) ⇒ Types::ListTargetResourceTypesResponse
Lists the target resource types.
-
#start_experiment(params = {}) ⇒ Types::StartExperimentResponse
Starts running an experiment from the specified experiment template.
-
#stop_experiment(params = {}) ⇒ Types::StopExperimentResponse
Stops the specified experiment.
-
#tag_resource(params = {}) ⇒ Struct
Applies the specified tags to the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes the specified tags from the specified resource.
-
#update_experiment_template(params = {}) ⇒ Types::UpdateExperimentTemplateResponse
Updates the specified experiment template.
-
#update_safety_lever_state(params = {}) ⇒ Types::UpdateSafetyLeverStateResponse
Updates the specified safety lever state.
-
#update_target_account_configuration(params = {}) ⇒ Types::UpdateTargetAccountConfigurationResponse
Updates the target account configuration for the specified experiment template.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
473 474 475 |
# File 'lib/aws-sdk-fis/client.rb', line 473 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2060 2061 2062 |
# File 'lib/aws-sdk-fis/client.rb', line 2060 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2063 2064 2065 |
# File 'lib/aws-sdk-fis/client.rb', line 2063 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 |
# File 'lib/aws-sdk-fis/client.rb', line 2033 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::FIS') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-fis' context[:gem_version] = '1.61.0' Seahorse::Client::Request.new(handlers, context) end |
#create_experiment_template(params = {}) ⇒ Types::CreateExperimentTemplateResponse
Creates an experiment template.
An experiment template includes the following components:
-
Targets: A target can be a specific resource in your Amazon Web Services environment, or one or more resources that match criteria that you specify, for example, resources that have specific tags.
-
Actions: The actions to carry out on the target. You can specify multiple actions, the duration of each action, and when to start each action during an experiment.
-
**Stop conditions**: If a stop condition is triggered while an experiment is running, the experiment is automatically stopped. You can define a stop condition as a CloudWatch alarm.
For more information, see [experiment templates] in the *Fault Injection Service User Guide*.
[1]: docs.aws.amazon.com/fis/latest/userguide/experiment-templates.html
674 675 676 677 |
# File 'lib/aws-sdk-fis/client.rb', line 674 def create_experiment_template(params = {}, = {}) req = build_request(:create_experiment_template, params) req.send_request() end |
#create_target_account_configuration(params = {}) ⇒ Types::CreateTargetAccountConfigurationResponse
Creates a target account configuration for the experiment template. A target account configuration is required when ‘accountTargeting` of `experimentOptions` is set to `multi-account`. For more information, see [experiment options] in the *Fault Injection Service User Guide*.
[1]: docs.aws.amazon.com/fis/latest/userguide/experiment-options.html
732 733 734 735 |
# File 'lib/aws-sdk-fis/client.rb', line 732 def create_target_account_configuration(params = {}, = {}) req = build_request(:create_target_account_configuration, params) req.send_request() end |
#delete_experiment_template(params = {}) ⇒ Types::DeleteExperimentTemplateResponse
Deletes the specified experiment template.
805 806 807 808 |
# File 'lib/aws-sdk-fis/client.rb', line 805 def delete_experiment_template(params = {}, = {}) req = build_request(:delete_experiment_template, params) req.send_request() end |
#delete_target_account_configuration(params = {}) ⇒ Types::DeleteTargetAccountConfigurationResponse
Deletes the specified target account configuration of the experiment template.
840 841 842 843 |
# File 'lib/aws-sdk-fis/client.rb', line 840 def delete_target_account_configuration(params = {}, = {}) req = build_request(:delete_target_account_configuration, params) req.send_request() end |
#get_action(params = {}) ⇒ Types::GetActionResponse
Gets information about the specified FIS action.
877 878 879 880 |
# File 'lib/aws-sdk-fis/client.rb', line 877 def get_action(params = {}, = {}) req = build_request(:get_action, params) req.send_request() end |
#get_experiment(params = {}) ⇒ Types::GetExperimentResponse
Gets information about the specified experiment.
967 968 969 970 |
# File 'lib/aws-sdk-fis/client.rb', line 967 def get_experiment(params = {}, = {}) req = build_request(:get_experiment, params) req.send_request() end |
#get_experiment_target_account_configuration(params = {}) ⇒ Types::GetExperimentTargetAccountConfigurationResponse
Gets information about the specified target account configuration of the experiment.
1002 1003 1004 1005 |
# File 'lib/aws-sdk-fis/client.rb', line 1002 def get_experiment_target_account_configuration(params = {}, = {}) req = build_request(:get_experiment_target_account_configuration, params) req.send_request() end |
#get_experiment_template(params = {}) ⇒ Types::GetExperimentTemplateResponse
Gets information about the specified experiment template.
1075 1076 1077 1078 |
# File 'lib/aws-sdk-fis/client.rb', line 1075 def get_experiment_template(params = {}, = {}) req = build_request(:get_experiment_template, params) req.send_request() end |
#get_safety_lever(params = {}) ⇒ Types::GetSafetyLeverResponse
Gets information about the specified safety lever.
1106 1107 1108 1109 |
# File 'lib/aws-sdk-fis/client.rb', line 1106 def get_safety_lever(params = {}, = {}) req = build_request(:get_safety_lever, params) req.send_request() end |
#get_target_account_configuration(params = {}) ⇒ Types::GetTargetAccountConfigurationResponse
Gets information about the specified target account configuration of the experiment template.
1141 1142 1143 1144 |
# File 'lib/aws-sdk-fis/client.rb', line 1141 def get_target_account_configuration(params = {}, = {}) req = build_request(:get_target_account_configuration, params) req.send_request() end |
#get_target_resource_type(params = {}) ⇒ Types::GetTargetResourceTypeResponse
Gets information about the specified resource type.
1173 1174 1175 1176 |
# File 'lib/aws-sdk-fis/client.rb', line 1173 def get_target_resource_type(params = {}, = {}) req = build_request(:get_target_resource_type, params) req.send_request() end |
#list_actions(params = {}) ⇒ Types::ListActionsResponse
Lists the available FIS actions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1218 1219 1220 1221 |
# File 'lib/aws-sdk-fis/client.rb', line 1218 def list_actions(params = {}, = {}) req = build_request(:list_actions, params) req.send_request() end |
#list_experiment_resolved_targets(params = {}) ⇒ Types::ListExperimentResolvedTargetsResponse
Lists the resolved targets information of the specified experiment.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1268 1269 1270 1271 |
# File 'lib/aws-sdk-fis/client.rb', line 1268 def list_experiment_resolved_targets(params = {}, = {}) req = build_request(:list_experiment_resolved_targets, params) req.send_request() end |
#list_experiment_target_account_configurations(params = {}) ⇒ Types::ListExperimentTargetAccountConfigurationsResponse
Lists the target account configurations of the specified experiment.
1305 1306 1307 1308 |
# File 'lib/aws-sdk-fis/client.rb', line 1305 def list_experiment_target_account_configurations(params = {}, = {}) req = build_request(:list_experiment_target_account_configurations, params) req.send_request() end |
#list_experiment_templates(params = {}) ⇒ Types::ListExperimentTemplatesResponse
Lists your experiment templates.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1350 1351 1352 1353 |
# File 'lib/aws-sdk-fis/client.rb', line 1350 def list_experiment_templates(params = {}, = {}) req = build_request(:list_experiment_templates, params) req.send_request() end |
#list_experiments(params = {}) ⇒ Types::ListExperimentsResponse
Lists your experiments.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1406 1407 1408 1409 |
# File 'lib/aws-sdk-fis/client.rb', line 1406 def list_experiments(params = {}, = {}) req = build_request(:list_experiments, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for the specified resource.
1435 1436 1437 1438 |
# File 'lib/aws-sdk-fis/client.rb', line 1435 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_target_account_configurations(params = {}) ⇒ Types::ListTargetAccountConfigurationsResponse
Lists the target account configurations of the specified experiment template.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1481 1482 1483 1484 |
# File 'lib/aws-sdk-fis/client.rb', line 1481 def list_target_account_configurations(params = {}, = {}) req = build_request(:list_target_account_configurations, params) req.send_request() end |
#list_target_resource_types(params = {}) ⇒ Types::ListTargetResourceTypesResponse
Lists the target resource types.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1521 1522 1523 1524 |
# File 'lib/aws-sdk-fis/client.rb', line 1521 def list_target_resource_types(params = {}, = {}) req = build_request(:list_target_resource_types, params) req.send_request() end |
#start_experiment(params = {}) ⇒ Types::StartExperimentResponse
Starts running an experiment from the specified experiment template.
1631 1632 1633 1634 |
# File 'lib/aws-sdk-fis/client.rb', line 1631 def start_experiment(params = {}, = {}) req = build_request(:start_experiment, params) req.send_request() end |
#stop_experiment(params = {}) ⇒ Types::StopExperimentResponse
Stops the specified experiment.
1721 1722 1723 1724 |
# File 'lib/aws-sdk-fis/client.rb', line 1721 def stop_experiment(params = {}, = {}) req = build_request(:stop_experiment, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Applies the specified tags to the specified resource.
1749 1750 1751 1752 |
# File 'lib/aws-sdk-fis/client.rb', line 1749 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes the specified tags from the specified resource.
1775 1776 1777 1778 |
# File 'lib/aws-sdk-fis/client.rb', line 1775 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_experiment_template(params = {}) ⇒ Types::UpdateExperimentTemplateResponse
Updates the specified experiment template.
1943 1944 1945 1946 |
# File 'lib/aws-sdk-fis/client.rb', line 1943 def update_experiment_template(params = {}, = {}) req = build_request(:update_experiment_template, params) req.send_request() end |
#update_safety_lever_state(params = {}) ⇒ Types::UpdateSafetyLeverStateResponse
Updates the specified safety lever state.
1981 1982 1983 1984 |
# File 'lib/aws-sdk-fis/client.rb', line 1981 def update_safety_lever_state(params = {}, = {}) req = build_request(:update_safety_lever_state, params) req.send_request() end |
#update_target_account_configuration(params = {}) ⇒ Types::UpdateTargetAccountConfigurationResponse
Updates the target account configuration for the specified experiment template.
2024 2025 2026 2027 |
# File 'lib/aws-sdk-fis/client.rb', line 2024 def update_target_account_configuration(params = {}, = {}) req = build_request(:update_target_account_configuration, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2053 2054 2055 |
# File 'lib/aws-sdk-fis/client.rb', line 2053 def waiter_names [] end |